Module mvreg

Module mvreg 

Multi-Value Register CRDT

The Multi-Value Register (MV-Register) maintains a set of concurrent values instead of choosing a single winner. Each value is tagged with a unique identifier (dot) to distinguish different writes.

When concurrent writes occur, the register contains all of them until one of them is explicitly observed and the others are discarded.

Structs

Dot
A unique identifier for a write operation
MVRegister
A Multi-Value Register CRDT