pub struct ORSet<T: Ord + Clone> { /* private fields */ }Expand description
An Observed-Remove Set (OR-Set) CRDT with add-wins semantics.
Each insertion is tagged with a globally unique Tag. A remove operation
only removes the tags that were observed at the time of removal. This means
a concurrent add and remove results in the element being present (add wins).
Supports delta-state replication via the DeltaCRDT trait.
Implementations